@@ -6,10 +6,13 @@ int main(int argc, char *argv[])
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
+  int port=5050;
+  int remote_port1=5051;
+  int remote_port2=5052;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5050, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  agency = MC_Initialize(port, &options);
 
   printf("Mobile-C Started\n");
   /* Note: The third argument of the following function may also be a
@@ -17,13 +20,13 @@ int main(int argc, char *argv[])
   MC_SendAgentMigrationMessageFile(agency,
       "test1.xml",
       "localhost",
-      5051);
+      remote_port1);
   printf("Press 'enter' to send the next agent.\n");
   getchar();
   MC_SendAgentMigrationMessageFile(agency,
       "test2.xml",
       "localhost",
-      5052);
+      remote_port2);
   MC_End(agency);
   exit(0);
 }
