@@ -12,7 +12,7 @@ int main(int argc, char *argv[])
   int local_port = 5052;
  
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
   agency = MC_Initialize(local_port, &options);
 
   printf("Mobile-C Started\n");
