@@ -6,10 +6,12 @@ int main(int argc, char *argv[])
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
+  int port=5050;
+  int remote_port = 5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5050, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  agency = MC_Initialize(port, &options);
 
   printf("Mobile-C Started\n");
   /* Note: The third argument of the following function may also be a
@@ -17,7 +19,7 @@ int main(int argc, char *argv[])
   MC_SendAgentMigrationMessageFile(agency,
       "test1.xml",
       "localhost",
-      5051);
+      remote_port);
   MC_End(agency);
   exit(0);
 }
