@@ -11,22 +11,25 @@ int main(int argc, char *argv[])
     MCAgency_t agency2;
     MCAgencyOptions_t options;
     int i;
+    int port1 = 5051;
+    int port2 = 5052;
 
     MCAgent_t agent;
     MCAgent_t agent_copy;
 
     MC_InitializeAgencyOptions(&options);
+
     /* We want _all_ the threads on: EXCEPT, the command prompt thread */
     for (i = 0; i < MC_THREAD_ALL; i++) {
         MC_SetThreadOn(&options, i);
     }
-    MC_SetThreadOff(&options, MC_THREAD_CP);  
+    MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
 
     agency1 = MC_Initialize(
-        5051,
+        port1,
         &options);
     agency2 = MC_Initialize(
-        5052,
+        port2,
         &options);
 
     while(1) {
