@@ -9,7 +9,8 @@ using System.Threading;
  * 1. Create your desired type of project.
  * 2. Add a reference to the LibMC project.
  * 3. Add "using LibmC;" where necessary.
- * 4. For any XML files you want to use, set "Copy to output directory" to "Copy Always" or "Copy if newer."
+ * 4. For any XML files you want to use, 
+ *    set "Copy to output directory" to "Copy Always" or "Copy if newer."
  * 5. Set working directory if desired.
  * 6. Enable unmanaged code debugging if desired.
  */
@@ -51,17 +52,21 @@ namespace LibMCFipaTest
             Console.WriteLine("Sleeping while the agents load.");
             Thread.Sleep(3000);
 
-            Console.WriteLine("Press 'enter' to send an acl message to the agent.");
+            Console.WriteLine("Press 'enter' to send " + 
+                "an acl message to the agent.");
             Console.ReadLine();
 
             MCAclMessage tmp = new MCAclMessage();
             tmp.New();
-            tmp.SetPerformative(MC_FipaPerformative_e.FIPA_INFORM);
+            tmp.SetPerformative(MCAclMessage.MC_FipaPerformative_e.FIPA_INFORM);
 
-            tmp.SetSender("agency", "http://" + host + ":" + localport.ToString() + "/acc");
-            tmp.AddReplyTo("mobagent2", "http://" + host + ":" + localport.ToString() + "/acc");
+            tmp.SetSender("agency", "http://" + host + ":" + 
+                localport.ToString() + "/acc");
+            tmp.AddReplyTo("mobagent2", "http://" + host + ":" + 
+                localport.ToString() + "/acc");
 
-            tmp.AddReceiver("mobagent1", "http://" + host + ":" + localport.ToString() + "/acc");
+            tmp.AddReceiver("mobagent1", "http://" + host + ":" + 
+                localport.ToString() + "/acc");
             tmp.SetContent("This is content. Yay!");
             Agency.AclSend(tmp);
             tmp.Destroy();
