@@ -1,3 +1,6 @@
+/* SVN FILE INFO
+ * $Revision: 182 $ : Last Committed Revision
+ * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -91,7 +94,7 @@ acc_Destroy(acc_p acc)
 acc_MessageHandlerThread(void* arg)
 #else
   DWORD WINAPI
-acc_MessageHandlerThread( LPVOID arg )
+acc_MessageHandlerThread(LPVOID arg)
 #endif
 {
   mc_platform_p mc_platform = (mc_platform_p)arg;
@@ -108,14 +111,12 @@ acc_MessageHandlerThread( LPVOID arg )
     MUTEX_LOCK(mc_platform->quit_lock);
     while(mc_platform->message_queue->size == 0 && !mc_platform->quit) {
       MUTEX_UNLOCK(mc_platform->quit_lock);
-      COND_WAIT
-        (
+      COND_WAIT(
          mc_platform->message_queue->cond,
-         mc_platform->message_queue->lock
-        );
+         mc_platform->message_queue->lock );
       MUTEX_LOCK(mc_platform->quit_lock);
     }
-    if ( mc_platform->message_queue->size == 0 && mc_platform->quit )
+    if (mc_platform->message_queue->size == 0 && mc_platform->quit)
     {
       MUTEX_UNLOCK(mc_platform->quit_lock);
       MUTEX_UNLOCK(mc_platform->message_queue->lock);
@@ -136,35 +137,31 @@ acc_MessageHandlerThread( LPVOID arg )
     MUTEX_UNLOCK(mc_platform->MC_signal_lock);
     MUTEX_LOCK(mc_platform->giant_lock);
     while(mc_platform->giant == 0) {
-      COND_WAIT
-        (
-         mc_platform->giant_cond,
-         mc_platform->giant_lock
-        );
+      COND_WAIT (
+          mc_platform->giant_cond,
+          mc_platform->giant_lock);
     }
     MUTEX_UNLOCK(mc_platform->giant_lock);
     /* See if the destination is here. If it is, process the message.
      * Otherwise, send the message to it's destination */
-    if( message->to_address == NULL) {
+    if(message->to_address == NULL) {
       /* Process message. Create the agent if it is an agent, or
        * process the ACL if it's an ACL message. */
       switch(message->message_type) {
         case MOBILE_AGENT:
-          agent = agent_Initialize
-            (
-             mc_platform,
-             message,
-             mobile_agent_counter
-            );
+          agent = agent_Initialize(
+              mc_platform,
+              message,
+              mobile_agent_counter);
           if (agent != NULL) {
             /* We need to make sure there are no agent-name collisions. */
             i = 1;
-            if( agent_queue_SearchName( mc_platform->agent_queue, agent->name ) ) {
+            if(agent_queue_SearchName(mc_platform->agent_queue, agent->name)) {
               origname = agent->name;
-              while( agent_queue_SearchName( mc_platform->agent_queue, agent->name ) ) {
+              while(agent_queue_SearchName(mc_platform->agent_queue, agent->name)) {
                 /* An agent with a matching name was found! For now, let us just
                  * rename the agent. */
-                tmpstr = (char*)malloc(sizeof(char)* strlen(origname)+7);
+                tmpstr = (char*)malloc(sizeof(char) * strlen(origname) + 7);
                 sprintf(tmpstr, "%s_%04d", origname, i);
                 agent->name = tmpstr;
                 i++;
@@ -174,11 +171,9 @@ acc_MessageHandlerThread( LPVOID arg )
               free(origname);
             }
             mobile_agent_counter++;
-            agent_queue_Add
-              (
-               mc_platform->agent_queue,
-               agent
-              );
+            agent_queue_Add(
+                mc_platform->agent_queue,
+                agent);
           }
           message_Destroy(message);
           /* Send MC_Signal */
@@ -188,10 +183,8 @@ acc_MessageHandlerThread( LPVOID arg )
           MUTEX_UNLOCK(mc_platform->MC_signal_lock);
           MUTEX_LOCK(mc_platform->giant_lock);
           while(mc_platform->giant == 0) {
-            COND_WAIT(
-                mc_platform->giant_cond,
-                mc_platform->giant_lock
-                );
+            COND_WAIT(mc_platform->giant_cond,
+                mc_platform->giant_lock);
           }
           MUTEX_UNLOCK(mc_platform->giant_lock);
           /* Set the ams to run */
@@ -206,23 +199,19 @@ acc_MessageHandlerThread( LPVOID arg )
           break;
         case RETURN_MSG:
           /* Add the persistent neutral agent. */
-          agent = agent_Initialize
-            (
-             mc_platform,
-             message,
-             mobile_agent_counter
-            );
+          agent = agent_Initialize(
+              mc_platform,
+              message,
+              mobile_agent_counter);
           if (agent != NULL) {
             MUTEX_LOCK(agent->lock);
             agent->datastate->persistent = 1;
             agent->agent_status = MC_AGENT_NEUTRAL;
             MUTEX_UNLOCK(agent->lock);
             mobile_agent_counter++;
-            agent_queue_Add
-              (
-               mc_platform->agent_queue,
-               agent
-              );
+            agent_queue_Add(
+                mc_platform->agent_queue,
+                agent);
           }
           message_Destroy(message);
           /* Send MC_Signal */
@@ -234,8 +223,7 @@ acc_MessageHandlerThread( LPVOID arg )
           while(mc_platform->giant == 0) {
             COND_WAIT(
                 mc_platform->giant_cond,
-                mc_platform->giant_lock
-                );
+                mc_platform->giant_lock);
           }
           MUTEX_UNLOCK(mc_platform->giant_lock);
           /* Set the ams to run */
@@ -244,7 +232,7 @@ acc_MessageHandlerThread( LPVOID arg )
           COND_BROADCAST(mc_platform->ams->runflag_cond);
           MUTEX_UNLOCK(mc_platform->ams->runflag_lock);
           break;
-/* MC_SECURITY */
+          /* MC_SECURITY */
 #ifdef MC_SECURITY
         case ENCRYPTED_DATA:
           if (mc_platform->enable_security) {
@@ -260,16 +248,16 @@ acc_MessageHandlerThread( LPVOID arg )
           break;
         case ENCRYPTION_INITIALIZE: 
           if (mc_platform->enable_security) {
-          asm_queue_Add
-            (
-             mc_platform->asm_queue,
-             asm_node_Initialize(message, mc_platform->security_manager)
-            );
-          /* Manually wake up the asm thread */
-          MUTEX_LOCK(mc_platform->asm_message_queue->lock);
-          COND_SIGNAL(mc_platform->asm_message_queue->cond);
-          MUTEX_UNLOCK(mc_platform->asm_message_queue->lock);
-          message_Destroy(message);
+            asm_queue_Add
+              (
+               mc_platform->asm_queue,
+               asm_node_Initialize(message, mc_platform->security_manager)
+              );
+            /* Manually wake up the asm thread */
+            MUTEX_LOCK(mc_platform->asm_message_queue->lock);
+            COND_SIGNAL(mc_platform->asm_message_queue->cond);
+            MUTEX_UNLOCK(mc_platform->asm_message_queue->lock);
+            message_Destroy(message);
           } else {
             WARN("mc_security not enabled. Discarding ENCRYPTION_INITIALIZE message.");
             message_Destroy(message);
@@ -277,11 +265,11 @@ acc_MessageHandlerThread( LPVOID arg )
           break;
         case REQUEST_ENCRYPTION_INITIALIZE:
           if (mc_platform->enable_security) {
-          asm_SendEncryptionData(
-              mc_platform->security_manager,
-              message->from_address
-              );
-          message_Destroy(message);
+            asm_SendEncryptionData(
+                mc_platform->security_manager,
+                message->from_address
+                );
+            message_Destroy(message);
           } else {
             WARN("mc_security not enabled. Discarding REQUEST_ENCRYPTION_INITIALIZE message.");
             message_Destroy(message);
