@@ -1,3 +1,6 @@
+/* SVN FILE INFO
+ * $Revision: 182 $ : Last Committed Revision
+ * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -1341,7 +1344,7 @@ int fipa_agent_identifier_set_Compose(dynstring_t* msg, fipa_agent_identifier_se
   int i;
   if(ids == NULL) return 0;
   if(ids->num == 0) return 0;
-  dynstring_Append(msg, "(sequence ");
+  dynstring_Append(msg, "(set ");
   for(i = 0; i < ids->num; i++) {
     fipa_agent_identifier_Compose(msg, ids->fipa_agent_identifiers[i]);
   }
