@@ -1,3 +1,6 @@
+/* SVN FILE INFO
+ * $Revision: 182 $ : Last Committed Revision
+ * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -946,6 +949,13 @@ fipa_envelope_Compose__params(fipa_acl_message_t* fipa_acl)
      MXML_ADD_TO_PARENT,
      fipa_envelope_Compose__date(fipa_acl)
     );
+  mxmlAdd
+    (
+     node,
+     MXML_ADD_AFTER,
+     MXML_ADD_TO_PARENT,
+     fipa_envelope_Compose__intended_receiver(fipa_acl)
+    );
 /*  mxmlAdd
     (
      node,
@@ -1039,10 +1049,14 @@ fipa_envelope_Compose__from(fipa_acl_message_t* fipa_acl)
         url_node = mxmlNewElement(
             addresses_node,
             "url" );
+        /*mxmlNewText(
+            url_node,
+            0,
+            fipa_acl->sender->addresses->urls[i]->str );*/
         mxmlNewText(
             url_node,
             0,
-            fipa_acl->sender->addresses->urls[i]->str );
+            "http://localhost:5555/acc");
       }
     }
   } else {
@@ -1120,3 +1134,47 @@ fipa_envelope_Compose__date(fipa_acl_message_t* fipa_acl)
   return node;
 }
 
+mxml_node_t*
+fipa_envelope_Compose__intended_receiver(fipa_acl_message_t* fipa_acl)
+{
+  int i;
+  int j;
+  mxml_node_t* node;
+  mxml_node_t* agent_identifier_node;
+  mxml_node_t* name_node;
+  mxml_node_t* addresses_node;
+  mxml_node_t* url_node;
+  node = mxmlNewElement(
+      NULL,
+      "intended-receiver");
+  i = 0;
+  agent_identifier_node = mxmlNewElement(
+      node,
+      "agent-identifier");
+  name_node = mxmlNewElement(
+      agent_identifier_node,
+      "name");
+  mxmlNewText(
+      name_node,
+      0,
+      fipa_acl->receiver->fipa_agent_identifiers[i]->name);
+
+  addresses_node = mxmlNewElement(
+      agent_identifier_node,
+      "addresses");
+  for(
+      j = 0; 
+      j < fipa_acl->receiver->fipa_agent_identifiers[i]->addresses->num;
+      j++
+     ) 
+  {
+    url_node = mxmlNewElement(
+        addresses_node,
+        "url" );
+    mxmlNewText(
+        url_node,
+        0,
+        fipa_acl->receiver->fipa_agent_identifiers[i]->addresses->urls[j]->str );
+  }
+  return node;
+}
