@@ -1,3 +1,6 @@
+/* SVN FILE INFO
+ * $Revision: 182 $ : Last Committed Revision
+ * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
 #include "fipa_acl.h"
 
 /* fipa_acl_envelope_Received */
@@ -136,3 +139,6 @@ fipa_envelope_Compose__payload_encoding(fipa_acl_message_t* fipa_acl);
 
 mxml_node_t*
 fipa_envelope_Compose__date(fipa_acl_message_t* fipa_acl);
+
+mxml_node_t*
+fipa_envelope_Compose__intended_receiver(fipa_acl_message_t* fipa_acl);
